@@ -19,9 +19,12 @@
 """
 import os
 
-def database_location():
-    return os.environ.get("DATABASE_LOCATION", "db")
 
+def database_location():
+    return os.environ.get("DATABASE_LOCATION", ".")
+
+
+#: Columns that represent the electricity avoided costs components that must be aggregated
 ACC_COMPONENTS_ELECTRICITY = [
     "total",
     "energy",
